==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesMap_bms.php <==
<?php
/** Basa Banyumasan (Basa Banyumasan)
 *
 * @ingroup Language
 * @file
 *
 * @author לערי ריינהארט
 */

$fallback = 'jv';

$messages = array(
'article'    => 'Isi tulisan',
'cancel'     => 'Ora Sida',
'mypage'     => 'Kaca inyong',
'mytalk'     => 'Catetan inyong',
'navigation' => 'pandhu arah',

'help'             => 'Rewang',
'search'           => 'golet tulisan',
'go'               => 'golet',
'history'          => 'sejarah kaca',
'history_short'    => 'Sejarah kaca',
'printableversion' => 'Edisi Cetak',
'edit'             => 'Sunting',
'delete'           => 'Busek',
'specialpage'      => 'Kaca khusus',
'articlepage'      => 'Deleng isi tulisan',
'talk'             => 'bahas',
'toolbox'          => 'perangkat',
'otherlanguages'   => 'basa liya',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Kedaden Anyar',
'mainpage'      => 'Kaca Utama',
'portal'        => 'Komunitas',

'editsection' => 'sunting',

# Login and logout pages
'login'         => 'Melebu',
'userlogin'     => 'Melebu / gawe kaca anggota (account)',
'logout'        => 'Metu',
'userlogout'    => 'Metu',
'createaccount' => 'Gawe Kaca Anggota',

# Edit pages
'savearticle' => 'Simpen',
'preview'     => 'Pra tayang',
'showpreview' => 'Pra tayang',
'showdiff'    => 'Deleng beda',

# Recent changes
'recentchanges' => 'Pengobahan',

# Recent changes linked
'recentchangeslinked' => 'Pengobahan terkait',

# Random page
'randompage' => 'Kaca Liya',

# Miscellaneous special pages
'move' => 'Pindah',

# Contributions
'contributions' => 'Tulisan anggota',
'mycontris'     => 'Tulisan inyong',

# What links here
'whatlinkshere' => 'Pranala Kaca Kiye',

# Special:SpecialPages
'specialpages' => 'Kaca-kaca khusus',

);

==> mediawiki-1.18.0rc1.tar.gz: mediawiki-1.18.0rc1/languages/messages/MessagesMap_bms.php <==
<?php
/** Basa Banyumasan (Basa Banyumasan)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author StefanusRA
 * @author לערי ריינהארט
 */

$fallback = 'jv';

$messages = array(
# Dates
'sunday'    => 'Minggu',
'monday'    => 'Senen',
'tuesday'   => 'Selasa',
'wednesday' => 'Rebo',
'thursday'  => 'Kemis',
'friday'    => 'Jemuwah',
'saturday'  => 'Setu',
'sun'       => 'Min',
'mon'       => 'Sen',
'tue'       => 'Sel',
'wed'       => 'Reb',
'thu'       => 'Kem',
'fri'       => 'Jem',
'sat'       => 'Set',
'january'   => 'Januari',
'february'  => 'Februari',
'march'     => 'Maret',
'april'     => 'April',
'may_long'  => 'Mei',
'june'      => 'Juni',
'july'      => 'Juli',

'article'    => 'Isi tulisan',
'cancel'     => 'Ora Sida',
'mypage'     => 'Kaca inyong',
'mytalk'     => 'Catetan inyong',
'navigation' => 'pandhu arah',

'help'             => 'Rewang',
'search'           => 'golet tulisan',
'go'               => 'golet',
'history'          => 'sejarah kaca',
'history_short'    => 'Sejarah kaca',
'printableversion' => 'Edisi Cetak',
'edit'             => 'Sunting',
'delete'           => 'Busek',
'specialpage'      => 'Kaca khusus',
'articlepage'      => 'Deleng isi tulisan',
'talk'             => 'bahas',
'toolbox'          => 'perangkat',
'otherlanguages'   => 'basa liya',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Kedaden Anyar',
'mainpage'      => 'Kaca Utama',
'portal'        => 'Komunitas',

'editsection' => 'sunting',

# Login and logout pages
'login'         => 'Melebu',
'userlogin'     => 'Melebu / gawe kaca anggota (account)',
'logout'        => 'Metu',
'userlogout'    => 'Metu',
'createaccount' => 'Gawe Kaca Anggota',

# Edit pages
'savearticle' => 'Simpen',
'preview'     => 'Pra tayang',
'showpreview' => 'Pra tayang',
'showdiff'    => 'Deleng beda',

# Recent changes
'recentchanges' => 'Pengobahan',

# Recent changes linked
'recentchangeslinked'         => 'Pengobahan terkait',
'recentchangeslinked-feed'    => 'Pengobahan terkait',
'recentchangeslinked-toolbox' => 'Pengobahan terkait',

# Random page
'randompage' => 'Kaca Liya',

# Miscellaneous special pages
'move' => 'Pindah',

# Contributions
'contributions' => 'Tulisan anggota',
'mycontris'     => 'Tulisan inyong',

# What links here
'whatlinkshere' => 'Pranala Kaca Kiye',

# Special:SpecialPages
'specialpages' => 'Kaca-kaca khusus',

);
